]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - stdout.c
Misc documentation cleanups related to select().
[paraslash.git] / stdout.c
index 71c45f69518b349d07143823003dedac9a0f5e2f..f31b8675d2d85900f4abf88c948fc45bbfc8f128 100644 (file)
--- a/stdout.c
+++ b/stdout.c
@@ -10,7 +10,7 @@
 #include "stdout.h"
 #include "buffer_tree.h"
 
/* Add STDOUT_FILENO to the write fd set if there is input data available. */
 static void stdout_pre_select(struct sched *s, void *context)
 {
        struct stdout_task *sot = context;
@@ -18,14 +18,14 @@ static void stdout_pre_select(struct sched *s, void *context)
 
        ret = btr_node_status(sot->btrn, 0, BTR_NT_LEAF);
        if (ret > 0)
-               para_fd_set(STDOUT_FILENO, &s->wfds, &s->max_fileno);
+               sched_monitor_writefd(STDOUT_FILENO, s);
        else if (ret < 0)
                sched_min_delay(s);
 }
 
 /*
- * This function writes input data from the buffer tree to stdout if
- * STDOUT_FILENO is writable.
+ * If input from the buffer tree is available and STDOUT_FILENO is ready, write
+ * as much as possible.
  */
 static int stdout_post_select(struct sched *s, void *context)
 {
@@ -10,7 +10,7 @@
 #include "buffer_tree.h"
 
-/* Add STDOUT_FILENO to the write fd set if there is input data available. */
+/* Monitor STDOUT_FILENO if there is input data available. */
 static void stdout_pre_select(struct sched *s, void *context)
 {